@@ -1,6 +1,6 @@
 package Test::Trap::Builder;
 
-use version; $VERSION = qv('0.2.1');
+use version; $VERSION = qv('0.2.4');
 
 use strict;
 use warnings;
@@ -8,7 +8,7 @@ use Data::Dump qw(dump);
 BEGIN {
   use Exporter ();
   *import = \&Exporter::import;
-  my @methods = qw( Next Exception Teardown Run TestAccessor TestFailure Prop DESTROY );
+  my @methods = qw( Next Exception ExceptionFunction Teardown Run TestAccessor TestFailure Prop DESTROY );
   our @EXPORT_OK = (@methods);
   our %EXPORT_TAGS = ( methods => \@methods );
 }
@@ -52,16 +52,25 @@ BEGIN {
     $self->$m(@_);
   }
 
+  sub ExceptionFunction {
+    my $self = shift;
+    my $exception = $self->Prop->{exception} ||= [];
+    $self->Prop->{exception_function} ||= sub {
+      push @$exception, @_;
+      local *@;
+      eval {
+        no warnings 'exiting';
+        last TEST_TRAP_BUILDER_INTERNAL_EXCEPTION;
+      };
+      # XXX: PANIC!  We returned!?!
+      CORE::exit(8); # XXX: Is there a more appropriate exit value?
+    };
+    return $self->Prop->{exception_function};
+  }
+
   sub Exception {
     my $self = shift;
-    push @{$self->Prop->{exception}}, @_;
-    local *@;
-    eval {
-      no warnings 'exiting';
-      last TEST_TRAP_BUILDER_INTERNAL_EXCEPTION;
-    };
-    # XXX: PANIC!  We returned!?!
-    CORE::exit(8); # XXX: Is there a more approprate exit value?
+    $self->ExceptionFunction->(@_);
   }
 }
 
@@ -81,9 +90,9 @@ sub trap {
   my $trap = bless { wantarray => (my $wantarray = wantarray) }, $trapper;
 TEST_TRAP_BUILDER_INTERNAL_EXCEPTION: {
     local *@;
-    $trap->Prop->{code}     = $code;
-    $trap->Prop->{layers}   = [@$layers];
-    $trap->Prop->{teardown} = [];
+    local $trap->Prop->{code} = $code;
+    $trap->Prop->{layers}     = [@$layers];
+    $trap->Prop->{teardown}   = [];
   TEST_TRAP_BUILDER_INTERNAL_EXCEPTION: {
       eval { $trap->Next; 1} or $trap->Exception("Rethrowing internal exception: $@");
     }
@@ -161,6 +170,7 @@ BEGIN { # Test callback registration and test method generation:
 
   my $wrong_leaveby = sub {
     ($accessor, $test, $trap, @arg) = @_;
+    require Test::More;
     my $Test = Test::More->builder;
     my $test_name_index = 0;
     for (@{$test->{argspec}}) {
@@ -366,7 +376,7 @@ Test::Trap::Builder - Backend for building test traps
 
 =head1 VERSION
 
-Version 0.2.1
+Version 0.2.4
 
 =head1 SYNOPSIS
 
@@ -541,6 +551,32 @@ regular control flow, like inside a DESTROY method or signal handler.
 If anything like this happens, CORE::exit will be called with an exit
 code of 8.
 
+Note: Direct calls to the Exception method within closures may cause
+circular references and so leakage.  To avoid this, fetch an
+L</"ExceptionFunction"> and call it from the closure instead.
+
+=head2 ExceptionFunction
+
+This method returns a function that may be called with the same effect
+as calling the L</"Exception"> method, allowing closures to throw
+exceptions without causing circular references by closing over the
+trap object itself.
+
+To illustrate:
+
+  # this will create a circular reference chain:
+  # trap object has property collection has teardown closure has trap object
+  $self->Teardown($_) for sub {
+    do_stuff() or $self->Exception("Stuff didn't work.");
+  };
+
+  # this will break the circular reference chain:
+  # teardown closure no longer has trap object
+  $Exception = $self->ExceptionFunction;
+  $self->Teardown($_) for sub {
+    do_things() or $Exception->("Things didn't work.");
+  };
+
 =head1 METHODS
 
 =head2 new
@@ -647,7 +683,7 @@ Trappers inherit test callbacks like methods (though they are not
 implemented as such; don't expect to find them in the symbol table).
 
 Test methods of the form I<ACCESSOR>_I<TEST> will be made available
-(directly or by inheritence) to every trapper that registers or
+(directly or by inheritance) to every trapper that registers or
 inherits both the accessor named I<ACCESSOR> and the test named
 I<TEST>.
 
@@ -767,11 +803,11 @@ Please report any bugs or feature requests directly to the author.
 
 =head1 AUTHOR
 
-Eirik Berg Hanssen, C<< <ebhanssen@allverden.no> >>
+Eirik Berg Hanssen, C<< <ebhanssen@cpan.org> >>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2006-2008 Eirik Berg Hanssen, All Rights Reserved.
+Copyright 2006-2014 Eirik Berg Hanssen, All Rights Reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
